<?php
require_once SSC_APPLICATION_PATH . '/forms/Abstract/Form.php';

class Ssc_Form_Metabox
    extends Ssc_Form_Abstract_Form
{
    protected $_dataKeys = array(
        'primary',
        'secondary',
    );
    protected $_postId;

    public function load()
    {
        /**
        * @var Ssc_Model_Options
        */
        $model = Ssc_Application::getModel('PostMeta')
            ->setPostId($this->_postId);

        $this->_values = array();

        $found = FALSE;
        foreach ($this->_dataKeys as $key) {
            $value = $model->getValue($key);
            if (!is_null($value)) {
                $found = TRUE;
            }
            $this->_values[$key] = $value;
        }

        if ($found) {
            $this->_validate();
        }

        return $this;
    }

    public function save()
    {
        /**
        * @var Ssc_Model_Options
        */
        $model = Ssc_Application::getModel('PostMeta')
            ->setPostId($this->_postId);

        foreach ($this->_dataKeys as $key) {
            $model->setValue($key, $this->getValue($key));
        }

        return $this;
    }

    protected function _validate()
    {
        // primary
        $value = trim($this->getValue('primary'));
        if ('' == $value) {
            $this->_errors['primary'] = 'Primary Keyword: This field is required and cannot be empty';
        }
        $primary = $this->_values['primary'] = $this->_filterKeyword($value);

        // secondary
        $value = $this->getValue('secondary');
        $lines = explode("\n", $value);
        foreach ($lines as $i=>$line) {
            $line = trim($line);
            if ('' == $line) {
                unset($lines[$i]);
                continue;
            }

            $line = $this->_filterKeyword($line);

            if ($line == $primary) {
                unset($lines[$i]);
                continue;
            }

            $lines[$i] = $line;
        }
        $this->_values['secondary'] = implode("\n", $lines);
    }

    protected function _filterKeyword($value)
    {
        return preg_replace('~\s+~', ' ', trim($value));
    }

    /**
    * Accessors
    */

    public function setPostId($value)
    {
        $this->_postId = $value;
        return $this;
    }

    public function getPostId()
    {
        return $this->_postId;
    }

    public function getDataKeys()
    {
        return $this->_dataKeys;
    }
}